searchData={"items":[{"type":"module","title":"Islands.Island","doc":"An island struct and functions for the _Game of Islands_.\n\nThe island struct contains the fields `type`, `origin`, `coords` and `hits`\nrepresenting the characteristics of an island in the _Game of Islands_.\n\n###","ref":"Islands.Island.html"},{"type":"module","title":"Based on the book [Functional Web Development](https://pragprog.com/titles/lhelph/functional-web-development-with-elixir-otp-and-phoenix/) by Lance Halvorsen. - Islands.Island","doc":"","ref":"Islands.Island.html#module-based-on-the-book-functional-web-development-https-pragprog-com-titles-lhelph-functional-web-development-with-elixir-otp-and-phoenix-by-lance-halvorsen"},{"type":"function","title":"Islands.Island.forested?/1","doc":"Checks if all the squares of `island` have been hit.","ref":"Islands.Island.html#forested?/1"},{"type":"function","title":"Islands.Island.grid_position/1","doc":"Converts `island`'s origin into a CSS grid position.","ref":"Islands.Island.html#grid_position/1"},{"type":"function","title":"Examples - Islands.Island.grid_position/1","doc":"iex> alias Islands.{Coord, Island}\n    iex> {:ok, origin} = Coord.new(2, 3)\n    iex> {:ok, atoll} = Island.new(:atoll, origin)\n    iex> Island.grid_position(atoll)\n    %{gridRowStart: 2, gridColumnStart: 3}","ref":"Islands.Island.html#grid_position/1-examples"},{"type":"function","title":"Islands.Island.guess/2","doc":"Returns `{:hit, updated_island}`, where updated_island is `island`\nconsequently updated if `guess` was a hit, or `:miss` otherwise.","ref":"Islands.Island.html#guess/2"},{"type":"function","title":"Islands.Island.hit_cells/1","doc":"Returns a list of hit \"cells\" relative to the `island`'s origin.","ref":"Islands.Island.html#hit_cells/1"},{"type":"function","title":"Examples - Islands.Island.hit_cells/1","doc":"iex> alias Islands.{Coord, Island}\n    iex> {:ok, origin} = Coord.new(2, 2)\n    iex> {:ok, atoll} = Island.new(:atoll, origin)\n    iex> {:ok, a1} = Coord.new(2, 2)\n    iex> {:ok, b1} = Coord.new(2, 3)\n    iex> {:ok, a3} = Coord.new(4, 2)\n    iex> {:hit, atoll} = Island.guess(atoll, a1)\n    iex> {:hit, atoll} = Island.guess(atoll, b1)\n    iex> {:hit, atoll} = Island.guess(atoll, a3)\n    iex> Island.hit_cells(atoll) |> Enum.sort()\n    [\"a1\", \"a3\", \"b1\"]","ref":"Islands.Island.html#hit_cells/1-examples"},{"type":"function","title":"Islands.Island.new/2","doc":"Returns `{:ok, island}` or `{:error, reason}` if given an invalid `type` or\n`origin`.","ref":"Islands.Island.html#new/2"},{"type":"function","title":"Examples - Islands.Island.new/2","doc":"iex> alias Islands.{Coord, Island}\n    iex> {:ok, origin} = Coord.new(1, 1)\n    iex> {:ok, island} = Island.new(:dot, origin)\n    iex> %Island{origin: ^origin, coords: coords, hits: hits} = island\n    iex> {coords, hits}\n    {MapSet.new([origin]), MapSet.new()}","ref":"Islands.Island.html#new/2-examples"},{"type":"function","title":"Islands.Island.new!/2","doc":"Returns an island struct or raises if given an invalid `type` or `origin`.","ref":"Islands.Island.html#new!/2"},{"type":"function","title":"Examples - Islands.Island.new!/2","doc":"iex> alias Islands.{Coord, Island}\n    iex> origin = Coord.new!(1, 1)\n    iex> %Island{coords: coords, hits: hits} = Island.new!(:dot, origin)\n    iex> {coords, hits}\n    {MapSet.new([origin]), MapSet.new()}\n\n    iex> alias Islands.{Coord, Island}\n    iex> origin = Coord.new!(10, 9)\n    iex> Island.new!(:square, origin)\n    ** (ArgumentError) cannot create island, reason: :invalid_island_location\n\n    iex> alias Islands.Island\n    iex> origin = %{row: 10, col: 9}\n    iex> Island.new!(:square, origin)\n    ** (ArgumentError) cannot create island, reason: :invalid_island_args","ref":"Islands.Island.html#new!/2-examples"},{"type":"function","title":"Islands.Island.overlaps?/2","doc":"Checks if `new_island` overlaps `island`.","ref":"Islands.Island.html#overlaps?/2"},{"type":"function","title":"Examples - Islands.Island.overlaps?/2","doc":"iex> alias Islands.{Coord, Island}\n    iex> square_origin = Coord.new!(1, 1)\n    iex> atoll_origin = Coord.new!(2, 2)\n    iex> square = Island.new!(:square, square_origin)\n    iex> atoll = Island.new!(:atoll, atoll_origin)\n    iex> Island.overlaps?(atoll, square)\n    true","ref":"Islands.Island.html#overlaps?/2-examples"},{"type":"type","title":"Islands.Island.coords/0","doc":"A set of squares","ref":"Islands.Island.html#t:coords/0"},{"type":"type","title":"Islands.Island.grid_cell/0","doc":"Grid cell e.g. \"a1\" or \"c3\"","ref":"Islands.Island.html#t:grid_cell/0"},{"type":"type","title":"Islands.Island.grid_position/0","doc":"A map representing a CSS grid position","ref":"Islands.Island.html#t:grid_position/0"},{"type":"type","title":"Islands.Island.t/0","doc":"An island struct for the Game of Islands","ref":"Islands.Island.html#t:t/0"},{"type":"type","title":"Islands.Island.type/0","doc":"Island type","ref":"Islands.Island.html#t:type/0"},{"type":"module","title":"Islands.Island.Offsets","doc":"Returns a list of offset tuples for each island type.","ref":"Islands.Island.Offsets.html"},{"type":"function","title":"Islands.Island.Offsets.new/1","doc":"Returns a list of offset tuples for the given `island_type`.","ref":"Islands.Island.Offsets.html#new/1"},{"type":"type","title":"Islands.Island.Offsets.col_offset/0","doc":"Column offset","ref":"Islands.Island.Offsets.html#t:col_offset/0"},{"type":"type","title":"Islands.Island.Offsets.row_offset/0","doc":"Row offset","ref":"Islands.Island.Offsets.html#t:row_offset/0"},{"type":"type","title":"Islands.Island.Offsets.t/0","doc":"A list of offset tuples","ref":"Islands.Island.Offsets.html#t:t/0"}],"content_type":"text/markdown"}